#!/usr/bin/env python3
# -*- python -*-

# Takes filename as argument

# Import required modules
import csv
import sqlite3
import os
import pwd
import sys

database_path = os.path.expanduser( '~/.local/share/linphone/friends.db' )

# Connecting to the geeks database
connection = sqlite3.connect(database_path)
 
# Creating a cursor object to execute
# SQL queries on a database table
cursor = connection.cursor()
 
# Table Definition
# create_table = '''CREATE TABLE friends(
#    id INTEGER PRIMARY KEY AUTOINCREMENT,
#    friend_list_id INTEGER,
#    sip_uri TEXT,
#    subscribe_policy INTEGER,
#    send_subscribe INTEGER,
#    ref_key TEXT,
#    vCard TEXT,
#    vCard_etag TEXT,
#    vCard_url TEXT,
#    presence_received INTEGER)
#    '''
 
# Opening the person-records.csv file
file = open(sys.argv[1])
 
# Reading the contents of the 
# person-records.csv file
contents = csv.reader(file)
# Skip header
next(contents)
 
# SQL query to insert data into the
# friends table
insert_records = "INSERT INTO friends (friend_list_id, sip_uri, subscribe_policy, send_subscribe, ref_key, vCard, vCard_etag, vCard_url, presence_received) VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?)"
 
# Importing the contents of the file 
# into our person table
cursor.executemany(insert_records, contents)

# Convert imported empty fields to NULL
update_ref_key = "UPDATE friends SET ref_key = NULL WHERE ref_key = ''"
cursor.execute(update_ref_key)
update_vCard_etag = "UPDATE friends SET vCard_etag = NULL WHERE vCard_etag = ''"
cursor.execute(update_vCard_etag)
update_vCard_url = "UPDATE friends SET vCard_url = NULL WHERE vCard_url = ''"
cursor.execute(update_vCard_url)

# Detect duplicates and remove them
delete_duplicates="DELETE FROM friends WHERE EXISTS (SELECT * FROM friends contacts WHERE friends.sip_uri = contacts.sip_uri AND friends.vCard = contacts.vCard AND friends.rowid > contacts.rowid)"
cursor.execute(delete_duplicates)
 
# SQL query to retrieve all data from
# the person table To verify that the
# data of the csv file has been successfully 
# inserted into the table
select_all = "SELECT * FROM friends"
rows = cursor.execute(select_all).fetchall()
 
# Output to the console screen
for r in rows:
    print(r)
 
# Committing the changes
connection.commit()
 
# closing the database connection
connection.close()
